@@ -1,45 +1,63 @@
-#' Set server URL
-#' This will set the server URL following the argument server
-#' in the main functions
-#' @param server the server name
-#' @param extension a character for the extension in the API call
+#' Set ClimMob Server URL
+#'
+#' Helper to construct the base URL for the ClimMob API.
+#' The function accepts either a known server name (e.g. `"climmob3"`,
+#' `"testing"`, `"1000farms"`, `"avisa"`, `"rtb"`) or a full/base URL
+#' (including local servers such as `"http://localhost:8000"`).
+#'
+#' Server names are matched case-insensitively, so for example
+#' `"AVISA"`, `"Avisa"`, and `"avisa"` are treated as the same server.
+#'
+#' @param server Character string. Either a known ClimMob server name
+#'   (e.g. `"climmob3"`, `"testing"`, `"1000farms"`, `"avisa"`, `"rtb"`)
+#'   or a full/base URL to a ClimMob-compatible server.
+#'   Defaults to `"climmob3"`.
+#' @param extension Character string specifying the path extension to be
+#'   appended after `"/api/"` in the URL (e.g. `"v1/projects"`).
+#'
+#' @return A length-one character vector with the full API URL.
+#'
+#' @keywords internal
+#' @examples
+#' # Default ClimMob3 server
+#' .set_url(extension = "v1/projects")
+#'
+#' # Testing server (any capitalization works)
+#' .set_url("TESTING", "v1/projects")
+#'
+#' # AVISA server
+#' .set_url("avisa", "v1/projects")
+#' .set_url("AVISA", "v1/projects")
+#'
+#' # Local development server
+#' .set_url("http://localhost:8000", "v1/projects")
 #' @noRd
-.set_url = function(server = "climmob3", extension = NULL){
+.set_url = function(server = "climmob3", extension = NULL) {
   
-  other_server = c("1000farms", "avisa", "rtb", "1000FARMS", "AVISA")
+  # Normalize input (so "AVISA", "AviSa", etc. become "avisa")
+  server_key = tolower(server)
   
-  known = server %in% other_server
+  # Mapping of normalized server names to their base URLs
+  predefined = list(
+    climmob3   = "https://climmob.net/climmob3",
+    testing    = "https://testing.climmob.net/climmob3",
+    "1000farms" = "https://1000farms.climmob.net",
+    avisa      = "https://avisa.climmob.net",
+    rtb        = "https://rtb.climmob.net"
+  )
   
-  if (known) {
-    
-    url = paste0("https://", server, ".climmob.net/api/", extension)
-    
-  }
-  
-  if (server == "testing") {
-    
-    url = paste0("https://", server, ".climmob.net/climmob3/api/", extension)
-    
-  }
-  
-  if (server == "climmob3") {
-    
-    url = paste0("https://climmob.net/climmob3/api/", extension)
-    
-  }
-  
-  if (isFALSE(known) & isFALSE(server == "climmob3") & isFALSE(server == "testing")) {
-    
-    stop("You are trying to reach an unknown server, please choose between '", 
-         paste(c("climmob3", unique(toupper(other_server))),
-               collapse = "', '"), "'\n")
-    
+  if (server_key %in% names(predefined)) {
+    base = predefined[[server_key]]
+  } else {
+    # Treat as full/local URL
+    base = server
   }
   
+  url = paste0(base, "/api/", extension)
   return(url)
-  
 }
 
+
 #' Get ClimMob projects 
 #'
 #' Fetch the status of ClimMob projects
